@@ -8,27 +8,28 @@ from inspect import getmembers, isfunction
 import scriptflow.core as sf
 import os
 
-from .glob import get_main_maestro
+from .glob import get_main_controller
 
-spec = importlib.util.spec_from_file_location("", os.getcwd() + "/sflow.py")
-foo = importlib.util.module_from_spec(spec)
-spec.loader.exec_module(foo)
+# loading the local sflow.py file
+def load_local_file(filename):
+    spec = importlib.util.spec_from_file_location("", os.getcwd() + "/" + filename)
+    foo = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(foo)
+    return foo
 
 """
     Main
 """
-async def main(func):
+async def main(func, controller):
 
-    asyncio.create_task( get_main_maestro().start_loops() )
+    asyncio.create_task( controller.start_loops() )
     os.makedirs('.sf', exist_ok=True)
 
     await func()      
-    # await asyncio.gather(cf_vdec_growth(), cf_vdec_level())
-    # requests.get('http://scriptflow.lamadon.com/test.php?hash=12345&running=10')
-
+    
     # let the other guys finish
     await asyncio.sleep(1)
-    get_main_maestro().last_word()
+    controller.last_word()
 
 
 @click.group()
@@ -37,7 +38,10 @@ def cli():
 
 @cli.command()
 @click.argument('name')
-def run(name=""):
+@click.option('-f', '--force', 'force')
+def run(name="",force=None,load="sflow.py"):
+
+    foo = load_local_file("sflow.py")
 
     func_names = {k:v for (k,v) in getmembers(foo, isfunction)}
     flows = [w.replace("flow_","") for w in func_names.keys() if w.startswith("flow_")]
@@ -47,7 +51,11 @@ def run(name=""):
         return()
 
     func = func_names["flow_{}".format(name)]
-    asyncio.run(main(func))
+
+    controller = get_main_controller()
+    controller.set_force_string(force)
+    
+    asyncio.run(main(func, controller))
 
 # if __name__ == '__main__':
 #     cli()
\ No newline at end of file
